@@ -6,7 +6,7 @@ Examples of use:
 >>> from phonenumbers.util import prnt  # equivalent to Py3k print()
 >>> x = phonenumbers.parse("+442083661177", None)
 >>> prnt(x)
-Country Code: 44 National Number: 2083661177 Leading Zero(s): False
+Country Code: 44 National Number: 2083661177
 >>> type(x)
 <class 'phonenumbers.phonenumber.PhoneNumber'>
 >>> str(phonenumbers.format_number(x, phonenumbers.PhoneNumberFormat.NATIONAL))
@@ -17,7 +17,7 @@ Country Code: 44 National Number: 2083661177 Leading Zero(s): False
 '+442083661177'
 >>> y = phonenumbers.parse("020 8366 1177", "GB")
 >>> prnt(y)
-Country Code: 44 National Number: 2083661177 Leading Zero(s): False
+Country Code: 44 National Number: 2083661177
 >>> x == y
 True
 >>>
@@ -132,7 +132,7 @@ from .phonenumbermatcher import PhoneNumberMatch, PhoneNumberMatcher, Leniency
 
 # Version number is taken from the upstream libphonenumber version
 # together with an indication of the version of the Python-specific code.
-__version__ = "6.2.0"
+__version__ = "6.3.0"
 
 __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'REGION_CODE_FOR_NON_GEO_ENTITY', 'NumberFormat', 'PhoneNumberDesc', 'PhoneMetadata',
